@@ -36,11 +36,12 @@ class Optimizer:
 
         self.results_path = self.communication_obj.results_path
 
+        algorithm_dict = optimization_dict['algorithm_settings']
         self.optimizer_attribute = dynamic_import(
-            attribute=optimization_dict.setdefault("opti_algorithm_attribute", None),
-            module_name=optimization_dict.setdefault("opti_algorithm_module", None),
-            class_name=optimization_dict.setdefault("opti_algorithm_class", None),
-            name=optimization_dict.setdefault("opti_algorithm_name", None),
+            attribute=algorithm_dict.setdefault("algorithm_attribute", None),
+            module_name=algorithm_dict.setdefault("algorithm_module", None),
+            class_name=algorithm_dict.setdefault("algorithm_class", None),
+            name=algorithm_dict.setdefault("algorithm_name", None),
             class_type='algorithm'
         )
 
